#if DEBUG

using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Text;

namespace PicasaWebDownloader
{
    /// <summary>
    /// Utility class which processes IANA's gTLD/ccTLD listing and generates a regular
    /// expression which matches them.
    /// </summary>
    public class GenerateTLDRegex
    {
        /// <summary>
        /// The URL for the official IANA TLD listing.
        /// </summary>
        static readonly Uri ianaTLDList = new Uri( "http://data.iana.org/TLD/tlds-alpha-by-domain.txt" );

        /// <summary>
        /// The line length limit (in characters) for the TLD regex.
        /// </summary>
        const int LineLengthLimit = 70;

        public void ReadTLDListAndGenerateRegex()
        {
            IList<string> tlds = new List<string>();

            // First, make the web requet to IANA's list and generate the list of TLDs
            HttpWebRequest req = (HttpWebRequest) WebRequest.Create( ianaTLDList );
            using ( HttpWebResponse resp = (HttpWebResponse) req.GetResponse() )
            using ( Stream respStream = resp.GetResponseStream() )
            using ( StreamReader sr = new StreamReader( respStream,
                Encoding.GetEncoding( resp.ContentEncoding != null && resp.ContentEncoding.Length > 0 
                ? resp.ContentEncoding : "utf-8" ) ) )
            {
                string line;
                while ( ( line = sr.ReadLine() ) != null )
                {
                    // Skip comments
                    if ( line.StartsWith( "#" ) )
                        continue;

                    // Skip weird XN--... entries
                    if ( line.Contains( "--" ) )
                        continue;

                    tlds.Add( line );
                }
            }

            // Next, construct the regex
            int lineIndex = 0;
            StringBuilder sb = new StringBuilder();
            bool first = true;
            foreach ( string tld in tlds )
            {
                if ( !first )
                    sb.Append( '|' );
                else
                    first = false;
                sb.Append( tld );

                if ( sb.Length - lineIndex >= LineLengthLimit )
                {
                    lineIndex = sb.Length;
                    sb.Append( '\n' );
                }
            }

            // And output on the console
            Console.WriteLine( sb.ToString() );
        }

        public static void Main( string[] args )
        {
            new GenerateTLDRegex().ReadTLDListAndGenerateRegex();
        }
    }
}

#endif